Module hooks

Module hooks 

Domain-specific hook event types for the agentic pipeline.

Each struct implements rskit_hook::Event so it can be emitted through a rskit_hook::HookRegistry.

Structs

OnError
Fired when an error occurs anywhere in the pipeline.
OnEvent
Canonical observe-only event stream observation.
OnMCPCall
Canonical observe-only MCP call event.
OnMCPResult
Canonical observe-only MCP result event.
PostLLMCall
Fired after an LLM completion response is received.
PostToolCall
Fired after a tool call completes.
PreLLMCall
Fired before an LLM completion request is sent.
PreToolCall
Fired before a tool call is executed.
TurnEnd
Fired at the end of an agent turn.
TurnStart
Fired at the start of an agent turn.

Functions

on_error_type
Event type for OnError.
on_event_type
Event type for canonical stream/event observations.
on_llm_call_type
Event type for canonical on_llm_call observations.
on_llm_response_type
Event type for canonical on_llm_response observations.
on_mcp_call_type
Event type for canonical MCP call observations.
on_mcp_result_type
Event type for canonical MCP result observations.
on_tool_call_type
Event type for canonical on_tool_call observations.
on_tool_result_type
Event type for canonical on_tool_result observations.
on_turn_complete_type
Event type for canonical TurnEnd.
on_turn_start_type
Event type for canonical TurnStart.
post_llm_call_type
Event type for LLM-response observations.
post_tool_call_type
Event type for tool-result observations.
pre_llm_call_type
Event type for PreLLMCall.
pre_tool_call_type
Event type for PreToolCall.
turn_end_type
Event type for TurnEnd.
turn_start_type
Event type for TurnStart.