#[non_exhaustive]pub enum StopReason {
EndTurn,
MaxTurns,
MaxTokens,
WallClockExceeded,
MaxToolCallsExceeded,
Cancelled,
Aborted,
}Expand description
Why the agent loop terminated.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EndTurn
The model finished its response without requesting any tool calls.
MaxTurns
Reached the configured maximum number of turns.
MaxTokens
Exceeded the token budget.
WallClockExceeded
Exceeded the wall-clock budget.
MaxToolCallsExceeded
Exceeded the maximum tool-call budget.
Cancelled
The run was cancelled.
Aborted
Aborted due to a hook handler, model error, or content filter.