pub struct Agent { /* private fields */ }Expand description
A multi-turn agentic loop that drives an LLM provider, executes tool calls, and emits hook events at each lifecycle point.
Implementations
Sourceimpl Agent
impl Agent
Sourcepub fn new(provider: Arc<dyn Provider>, config: AgentConfig) -> Self
pub fn new(provider: Arc<dyn Provider>, config: AgentConfig) -> Self
Create a new agent with the given provider and configuration.
Sourcepub fn with_defaults(provider: Arc<dyn Provider>) -> Self
pub fn with_defaults(provider: Arc<dyn Provider>) -> Self
Create a new agent with the locked default configuration.